=====================
unisos.common Library
=====================

.. contents::
   :depth: 3
..

Overview
========

Common UnISOS (Unix Internet Services OS) Library is part of BISOS
(ByStar Internet Services OS).

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Usage
=====

::

   from  unisos import icm

Installation
============

::

   pip install unisos.common

See Also
========

unisos.ucf unisos.icm unisos.common
